@@ -81,7 +81,7 @@ class Base(object):
     def _load_all_fileds(self):
         pass
 
-    def create(self, table, colums, show_sql=False):
+    def create(self, table, colums, table_comment='',show_sql=False):
         sql = 'create table %s(' % table
 
         tail = ''
@@ -95,6 +95,7 @@ class Base(object):
 
         tail = tail[:-1] + ')'
         sql += tail
+        sql += 'engine=innodb,charset=utf8,comment="%s"'%table_comment
         self.query(sql, show_sql)
         self.db.commit()
         return
